==> dhall-lsp-server-1.1.4-21-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-Be3rCLORxv3Jc67pvXEZvc
key:                  dhall-lsp-server-1.1.4-Be3rCLORxv3Jc67pvXEZvc
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  40fb9a4e04f06cd489fb745d60e8cde9
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-Be3rCLORxv3Jc67pvXEZvc
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb
    aeson-pretty-0.8.10-7dtxg6jHAs4ItgdWHojTS1 base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-Hhp4yJJfgcIMVKIO8OhoL
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    dhall-1.42.2-nJL8kjZmOX3g1CMbGwJ5G
    dhall-json-1.7.12-3lvsUdmi7e46clBrtpio5s directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF
    megaparsec-9.7.0-1voytdgo3wjFoCwR6CT9gz mtl-2.2.2
    network-uri-2.6.4.2-4Or7NcWT1BFGL9jaSnxRbG
    prettyprinter-1.7.1-JBUxpob9pPVLD8OaO2d4B1 text-2.0.2
    text-rope-0.3-LV2zkuoq1IwL5G8zG6wopc transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR
    uri-encode-1.5.0.7-2SwFmnYerN84AQoggj1vnx

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-lsp-server-1.1.4-22-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-lsp-server.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-lsp-server
version:              1.1.4
visibility:           public
id:                   dhall-lsp-server-1.1.4-B6cb0AJ1Ph2JuBfZ28Y4ce
key:                  dhall-lsp-server-1.1.4-B6cb0AJ1Ph2JuBfZ28Y4ce
license:              MIT
copyright:            2019 panaeon
maintainer:           Gabriella Gonzalez
author:               panaeon
homepage:
    https://github.com/dhall-lang/dhall-haskell/tree/master/dhall-lsp-server#readme

synopsis:             Language Server Protocol (LSP) server for Dhall
abi:                  5cbab621653cce76acd84a2dcf26e801
exposed:              True
exposed-modules:
    Dhall.LSP.Backend.Completion Dhall.LSP.Backend.Dhall
    Dhall.LSP.Backend.Diagnostics Dhall.LSP.Backend.Formatting
    Dhall.LSP.Backend.Freezing Dhall.LSP.Backend.Linting
    Dhall.LSP.Backend.Parsing Dhall.LSP.Backend.ToJSON
    Dhall.LSP.Backend.Typing Dhall.LSP.Handlers Dhall.LSP.Server
    Dhall.LSP.State

hidden-modules:       Paths_dhall_lsp_server Dhall.LSP.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-lsp-server-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-lsp-server
hs-libraries:         HSdhall-lsp-server-1.1.4-B6cb0AJ1Ph2JuBfZ28Y4ce
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb
    aeson-pretty-0.8.10-7dtxg6jHAs4ItgdWHojTS1 base-4.17.2.1
    bytestring-0.11.5.3 co-log-core-0.3.2.5-Hhp4yJJfgcIMVKIO8OhoL
    containers-0.6.7 data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy
    dhall-1.42.2-uds6wPOvCD14Ws2e0crWp
    dhall-json-1.7.12-HD4YIHmhUKOJxH7R8xJdqL directory-1.3.7.1
    filepath-1.4.2.2 lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF
    megaparsec-9.7.0-1voytdgo3wjFoCwR6CT9gz mtl-2.2.2
    network-uri-2.6.4.2-4Or7NcWT1BFGL9jaSnxRbG
    prettyprinter-1.7.1-JBUxpob9pPVLD8OaO2d4B1 text-2.0.2
    text-rope-0.3-LV2zkuoq1IwL5G8zG6wopc transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR
    uri-encode-1.5.0.7-2SwFmnYerN84AQoggj1vnx

haddock-interfaces:
    /usr/share/doc/dhall-lsp-server/html/dhall-lsp-server.haddock

haddock-html:         /usr/share/doc/dhall-lsp-server/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
